@@ -706,7 +706,7 @@ globus_options_entry_t                   gfork_l_opts_table[] =
         "Determines the program to execute for this service.",
         1, gfork_l_opts_server},
     {"server_args", "sa", NULL, "<arguments to the server>",
-        "List of arguments.  Comma seperated (or += if xinetd style)",
+        "List of arguments.  Comma separated (or += if xinetd style)",
         1, gfork_l_opts_server_args},
     {"port", "p", NULL, "<listener port number>",
         "The port number for the TCP listener",
@@ -733,7 +733,7 @@ globus_options_entry_t                   gfork_l_opts_table[] =
         "The name of the master program",
         1, gfork_l_opts_master},
     {"master_args", "ma", NULL, "<arguments to the master>",
-        "List of arguments.  Comma seperated (or += if xinetd style)",
+        "List of arguments.  Comma separated (or += if xinetd style)",
         1, gfork_l_opts_master_args},
     {"config_file", "c", NULL, NULL,
         "Print version information.",
